#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2000,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/db/Oracle8i/part_maint/compress_data.sh BL_core_schema_8.0.6.5.01_20090826  143644
# (#) 
#

SCRIPTNAME=`basename $0`

usage() {
    echo "$SCRIPTNAME -d StartDate -D EndDate -p period"
    echo " -d : Start date Format YYYYMMDD; must also specify end date"
    echo " -D : End date   Format YYYYMMDD; must also specify start date"
    echo " -p : D for daily, W for weekly, M for monthly  (default is D)"
    exit 1
}


START_DATE=N
END_DATE=N
ALL_FLAG=N
PERIOD=N

while [ $# -gt 0 ]
do

    case $1 in
	-d)
	    shift
            if [ $# -eq 0 ]
            then
                echo "Incomplete argument specification "
                echo " Usage ..."
                usage
            fi
	    START_DATE=$1
	    ;;

	-D)
	    shift
            if [ $# -eq 0 ]
            then
                echo "Incomplete argument specification "
                echo " Usage ..."
                usage
            fi
	    END_DATE=$1
	    ;;

    -p)
        shift
            if [ $# -eq 0 ]
            then
                echo "Incomplete argument specification "
                echo " Usage ..."
                usage
            fi
        PERIOD=$1
        ;;
    
    
	-a)
	    ALL_FLAG=Y
	    ;;
        -v)
           usage
           ;;

	*)
	    echo " Invalid parameter/incomplete parameter specification"
            echo "Usage ...."
	    usage
	    ;;
    esac

    shift

done

if [ "$START_DATE" == "N" -a "$END_DATE" != "N" ]
then
    echo "Error : *** Must specify start date also ***"
    echo " Usage is as follows ..."
    usage
fi

if [ "$START_DATE" != "N" -a "$END_DATE" == "N" ]
then
    echo "Error : *** Must specify end date also ***"
    echo " Usage is as follows ..."
    usage
fi

if [ "$PERIOD" == "N" ]
then
   PERIOD="D"
fi

if [ "$PERIOD" != "D" -a "$PERIOD" != "W" -a "$PERIOD" != "M" ]
then
    echo "Error : *** Period must be D, W or M ***"
    echo " Usage is as follows ..."
    usage
fi
  
sqlplus -s /NOLOG << !
connect $DBUSER/$DBPASSWD@$DBSID
set feed off
set serveroutput on size 1000000;
variable feedback_id_sh NUMBER
DECLARE
    feedback_id_sql NUMBER := 1;
    i_start_date DATE := NULL;
    i_end_date DATE := NULL;
    invalid_date_combo EXCEPTION;
    invalid_end_date EXCEPTION;
    invalid_start_date EXCEPTION;
BEGIN
  BEGIN
     SELECT to_date('$START_DATE','yyyymmdd')
       INTO i_start_date
     FROM dual;
  EXCEPTION
     WHEN OTHERS THEN
        RAISE invalid_start_date;
  END;
  BEGIN
     SELECT to_date('$END_DATE','yyyymmdd')
       INTO i_end_date
     FROM dual;
  EXCEPTION
     WHEN OTHERS THEN
        RAISE invalid_end_date;
  END;
  IF i_start_date > i_end_date THEN
        RAISE invalid_date_combo;
  END IF;
 
  IF ('$PERIOD' = 'D') THEN
     :feedback_id_sh := part_maint.compressdaily(i_start_date,i_end_date);
  ELSIF ('$PERIOD' = 'W') THEN
     :feedback_id_sh := part_maint.compressweekly(i_start_date,i_end_date);
  ELSE
     :feedback_id_sh := part_maint.compressmonthly(i_start_date,i_end_date);
  END IF;

EXCEPTION
    WHEN invalid_date_combo THEN
        dbms_output.put_line('Error : ***Start date should be less than end date*** ');
        :feedback_id_sh := 2;
    WHEN invalid_start_date THEN
        dbms_output.put_line('Error : ***Invalid start date*** ');
        :feedback_id_sh := 2;
    WHEN invalid_end_date THEN
        dbms_output.put_line('Error : ***Invalid end date*** ');
        :feedback_id_sh := 2;
END;
/
EXIT :feedback_id_sh
!
feedback_id=$?

if [ "$feedback_id" -eq 2 ]
then
    echo "Usage is as follows..."
    usage
fi

if [ "$feedback_id" -eq 0 ]
then
    echo "Compress failed..."
fi

if [ "$feedback_id" -eq 1 ]
then
    echo "Compress successful..."
fi
